@@ -2,8 +2,8 @@ use crate::{Context, Message};
 use serde::{Deserialize, Serialize};
 use std::{collections::HashMap, env, fs, path::Path};
 
-type KeyConfig = HashMap<Context, HashMap<String, Message>>;
-type ThemeConfig = HashMap<String, String>;
+pub type KeyConfig = HashMap<Context, HashMap<String, Message>>;
+pub type ThemeConfig = HashMap<String, String>;
 
 #[derive(Serialize, Deserialize, Debug, Clone)]
 pub struct Config {
