@@ -1,4 +1,3 @@
-use mpd::Subsystem;
 use serde::{Deserialize, Serialize};
 use strum_macros::EnumIter;
 
@@ -30,6 +29,9 @@ pub enum Message {
     VolumeUp,
     VolumeDown,
 
+    Rescan,
+    Seek(i32),
+
     UpdatePlayer,
     UpdateLibrary,
     UpdateQueue,
@@ -40,19 +42,6 @@ pub enum Message {
     Quit,
 }
 
-impl From<Subsystem> for Message {
-    fn from(subsystem: Subsystem) -> Self {
-        match subsystem {
-            Subsystem::Player => Message::UpdatePlayer,
-            Subsystem::Database => Message::UpdateLibrary,
-            Subsystem::Mixer => Message::UpdateVolume,
-            Subsystem::Playlist => Message::UpdatePlaylists,
-            Subsystem::Queue => Message::UpdateQueue,
-            _ => Message::None,
-        }
-    }
-}
-
 #[derive(Debug)]
 pub enum InputState {
     TextInput,
