@@ -1,4 +1,4 @@
-use crate::{model::AppHandle, util::ui_util::StatefulTable, MPDConnection};
+use crate::{util::ui_util::StatefulTable, App};
 use mpd::Song;
 
 #[derive(Debug, Clone)]
@@ -22,15 +22,20 @@ impl QueueModel {
     }
 }
 
-pub fn play(app: &AppHandle, connection: &mut MPDConnection) {
+pub fn play(app: &App) {
     let selected = app.model().queue.items.state.selected();
 
-    selected.and_then(|s| connection.switch(s as u32).ok());
+    // Lock on model is released, so we can lock connection
+    selected.and_then(|s| app.connection().switch(s as u32).ok());
 }
 
-pub fn update(app: &AppHandle, connection: &mut MPDConnection) {
-    let items = StatefulTable::with_items(connection.queue().unwrap_or_else(|_| Vec::new()));
-    let current_song = connection.currentsong().ok().and_then(|s| s);
+pub fn update(app: &App) {
+    let (items, current_song) = {
+        let mut connection = app.connection();
+        let items = StatefulTable::with_items(connection.queue().unwrap_or_else(|_| Vec::new()));
+        let current_song = connection.currentsong().ok().and_then(|s| s);
+        (items, current_song)
+    };
 
     let queue = &mut app.model().queue;
     queue.items = items;
