@@ -1,4 +1,4 @@
-use crate::{model::AppHandle, MPDConnection};
+use crate::App;
 
 #[derive(Debug, Clone)]
 pub struct VolumeModel {
@@ -17,23 +17,25 @@ impl VolumeModel {
     }
 }
 
-fn update_state_volume(app: &AppHandle, status: mpd::Status) {
+fn update_state_volume(app: &App, status: mpd::Status) {
     app.model().volume.volume = status.volume;
 }
 
-pub fn update(app: &AppHandle, connection: &mut MPDConnection) {
+pub fn update(app: &App) {
+    let mut connection = app.connection();
     let _ = connection
         .status()
         .map(|status| update_state_volume(app, status));
 }
 
-fn set_volume(app: &AppHandle, connection: &mut MPDConnection, new_volume: i8) {
+fn set_volume(app: &App, new_volume: i8) {
+    let mut connection = app.connection();
     if let Ok(()) = connection.volume(new_volume) {
         app.model().volume.volume = new_volume;
     }
 }
 
-pub fn change_volume(app: &AppHandle, connection: &mut MPDConnection, delta: i8) {
+pub fn change_volume(app: &App, delta: i8) {
     let volume = app.model().volume.volume;
-    set_volume(app, connection, volume + delta);
+    set_volume(app, volume + delta);
 }
