@@ -3,7 +3,11 @@ mod playlists;
 mod progress_bar;
 mod queue;
 
-use crate::{model::TabContent, AppBackend, Config, InputState, Model};
+use crate::{
+    model::TabContent,
+    util::{ui_util, ui_util::AppStyle},
+    AppBackend, InputState, Model, ThemeConfig,
+};
 
 use std::error::Error;
 
@@ -33,7 +37,7 @@ impl View {
         &mut self,
         terminal: &mut Terminal<AppBackend>,
         mut model: &mut Model,
-        _config: &Config,
+        theme: &ThemeConfig,
     ) -> Result<(), Box<dyn Error>> {
         terminal.draw(|f: &mut Frame<AppBackend>| {
             let size = f.size();
@@ -53,18 +57,20 @@ impl View {
             let block = Block::default().style(Style::default().fg(Color::Black));
             f.render_widget(block, size);
 
-            self.render_tabs(&mut model, f, chunks[0]);
+            self.render_tabs(&mut model, &theme, f, chunks[0]);
 
             match &model.current_content() {
-                TabContent::Library => library::view(&mut model.library, f, chunks[1]),
-                TabContent::Playlists => playlists::view(&mut model.playlists, f, chunks[1]),
-                TabContent::Queue => queue::view(&mut model.queue, f, chunks[1]),
+                TabContent::Library => library::view(&mut model.library, &theme, f, chunks[1]),
+                TabContent::Playlists => {
+                    playlists::view(&mut model.playlists, &theme, f, chunks[1])
+                }
+                TabContent::Queue => queue::view(&mut model.queue, &theme, f, chunks[1]),
             }
 
             match &model.input_state {
                 InputState::TextInput => {}
                 InputState::None => {
-                    progress_bar::view(&model.progress_bar, f, chunks[2]);
+                    progress_bar::view(&model.progress_bar, &theme, f, chunks[2]);
                 }
             }
         })?;
@@ -72,12 +78,23 @@ impl View {
         Ok(())
     }
 
-    fn render_tabs(&mut self, model: &mut Model, f: &mut Frame<AppBackend>, area: Rect) {
+    fn render_tabs(
+        &mut self,
+        model: &mut Model,
+        theme: &ThemeConfig,
+        f: &mut Frame<AppBackend>,
+        area: Rect,
+    ) {
         let mut titles = model
             .tabs
             .titles
             .iter()
-            .map(|t| Spans::from(Span::styled(t.clone(), Style::default().fg(Color::Yellow))))
+            .map(|t| {
+                Spans::from(Span::styled(
+                    t.clone(),
+                    ui_util::get_style(&theme, AppStyle::TabTitle),
+                ))
+            })
             .collect::<Vec<_>>();
 
         {
@@ -95,7 +112,7 @@ impl View {
         let tabs = Tabs::new(titles)
             .block(Block::default().borders(Borders::ALL))
             .select(model.tabs.index)
-            .style(Style::default().fg(Color::Cyan))
+            .style(ui_util::get_style(&theme, AppStyle::Border))
             .highlight_style(Style::default().add_modifier(Modifier::BOLD));
         f.render_widget(tabs, area);
     }
