@@ -1,15 +1,19 @@
-use crate::{model::QueueModel, AppBackend};
+use crate::{
+    model::QueueModel,
+    util::ui_util,
+    AppBackend, ThemeConfig,
+};
 
 use mpd::Song;
 use time::Duration;
 use tui::{
     layout::{Constraint, Rect},
-    style::{Color, Modifier, Style},
+    style::{Modifier, Style},
     terminal::Frame,
-    widgets::{Block, Borders, Row, Table},
+    widgets::{Row, Table},
 };
 
-pub fn view(queue: &mut QueueModel, f: &mut Frame<AppBackend>, area: Rect) {
+pub fn view(queue: &mut QueueModel, theme: &ThemeConfig, f: &mut Frame<AppBackend>, area: Rect) {
     let current_song_name: String = queue
         .current_song
         .clone()
@@ -25,12 +29,8 @@ pub fn view(queue: &mut QueueModel, f: &mut Frame<AppBackend>, area: Rect) {
         Row::Data(lines)
     });
     let items = Table::new(vec!["  #", "Artist", "Title", "🕔"].into_iter(), items)
-        .block(
-            Block::default()
-                .title("Queue")
-                .borders(Borders::ALL)
-                .style(Style::default().fg(Color::Cyan)),
-        )
+        .style(ui_util::table_style(&theme))
+        .block(ui_util::create_content_frame(&theme, "Queue".into()))
         .highlight_style(Style::default().add_modifier(Modifier::BOLD))
         .highlight_symbol("→ ")
         .widths(&[
